@@ -66,7 +66,7 @@ def backup_cib()
   # We use the pacemaker CIB folder because of its restricted access permissions
   cib = pcmk_tmpname("#{PCMK_TMP_BASE}/puppet-cib-backup", nil)
   cmd = "#{PCS_BIN} cluster cib #{cib}"
-  output = `#{cmd}`
+  output = `#{cmd} 2>&1`
   ret = $?
   if not ret.success?
     msg = "backup_cib: Running: #{cmd} failed with code: #{ret.exitstatus} -> #{output}"
@@ -97,7 +97,7 @@ def push_cib(cib)
   if has_diffagainst
     cmd += " diff-against=#{cib}.orig"
   end
-  output = `#{cmd}`
+  output = `#{cmd} 2>&1`
   ret = $?
   delete_cib(cib)
   if not ret.success?
@@ -145,6 +145,26 @@ def pcs(name, resource_name, cmd, tries=1, try_sleep=0,
   end
 end
 
+def pcs_without_push(name, resource_name, cmd, tries=1, try_sleep=0, post_success_sleep=0)
+  max_tries = tries
+  max_tries.times do |try|
+    try_text = max_tries > 1 ? "try #{try+1}/#{max_tries}: " : ''
+    Puppet.debug("#{try_text}#{PCS_BIN} #{cmd}")
+    pcs_out = `#{PCS_BIN} #{cmd} 2>&1`
+    if $?.exitstatus == 0
+      sleep post_success_sleep
+      return pcs_out
+    else
+      Puppet.debug("Error: #{pcs_out}")
+      sleep try_sleep
+    end
+    if try == max_tries-1
+      pcs_out_line = pcs_out.lines.first ? pcs_out.lines.first.chomp! : ''
+      raise Puppet::Error, "pcs #{name} failed: #{pcs_out_line}"
+    end
+  end
+end
+
 def pcs_create_with_verify(name, resource_name, cmd, tries=1, try_sleep=0)
   max_tries = tries
   max_tries.times do |try|
